@@ -49,7 +49,7 @@ function main (cxt) {
 // Note: A program shall not directly alter the contents of STATE.
 
     def('state', function () {
-        this.dpush(0); // TODO should be real state memory cell
+        this.dpush(this.state); // TODO should be real state memory cell
     }, cxt);
 
 
@@ -1168,6 +1168,8 @@ function main (cxt) {
     }, cxt, { immediate: true });
 
     def('>body', function () {
+        this.dpop();
+        this.dpush(this.O[this.L].body);
     }, cxt, { immediate: true });
 
 
