@@ -24,6 +24,10 @@ function core (cxt) {
         cxt.log('\n');
     }, cxt);
 
+    def('bl', function () {
+        this.dpush(32);
+    }, cxt);
+
     def('.', function () {
         cxt.log(' ' + this.dpop());
     }, cxt);
@@ -51,6 +55,8 @@ function core (cxt) {
 
     def('hex', function () { this.base = 16; }, cxt);
 
+    def('decimal', function () { this.base = 10; }, cxt);
+
 // tester
 
     def('testing', function () { this.io.parse('\\\n'); }, cxt);
