@@ -9,6 +9,8 @@ var def = require('./def');
 function main (cxt) {
     var mem = new ArrayBuffer(0x10000); // 3.3.3 Data space
     cxt.MEMi32 = new Int32Array(mem);
+    cxt.MEMi16 = new Int16Array(mem);
+    cxt.MEMi8  = new Int8Array(mem);
 
     cxt.here = 0; // in bytes
 
@@ -19,7 +21,13 @@ function main (cxt) {
     def ('!', function () {
         var t = this.dpop();
         var n = this.dpop();
-        this.MEMi32[t >> 2] = n; // TODO 32-bit write?
+        this.MEMi32[t >> 2] = n;
+    }, cxt);
+
+    def ('c!', function () {
+        var t = this.dpop();
+        var n = this.dpop();
+        this.MEMi8[t] = n;
     }, cxt);
 
     def('2!', function () {
@@ -49,8 +57,19 @@ function main (cxt) {
     }, cxt);
 
     def('@', function () {
-        var t = this.dpop();
-        this.dpush(this.MEMi32[t >> 2]); // TODO 32-bit read?
+        var addr = this.dpop();
+        this.dpush(this.MEMi32[addr >> 2]);
+    }, cxt);
+
+    def('c@', function () {
+        var addr = this.dpop();
+        this.dpush(this.MEMi8[addr]);
+    }, cxt);
+
+    def('2@', function () {
+        var addr = this.dpop();
+        this.dpush(this.MEMi32[addr >> 2]);
+        this.dpush(this.MEMi32[(addr >> 2) + 1]);
     }, cxt);
 
     def (',', function () {
@@ -59,6 +78,20 @@ function main (cxt) {
         this.here += 4;
     }, cxt);
 
+    def ('allot', function () {
+        this.here += this.dpop();
+    }, cxt);
+
+    def ('aligned', function () {
+        // this.dpush((this.dpop() + 3) & -4);
+        this.dpush(this.dpop());
+    }, cxt);
+
+    // def ('align', function () {
+    //     // this.dpush((this.dpop() + 3) & -4);
+    //     this.dpush(this.dpop());
+    // }, cxt);
+
 }
 
 module.exports = main;
