@@ -76,14 +76,14 @@ function stack (cxt) {
             var n = this.dpop() | 0;
             var m = this.dpop() | 0;
             var d = (m * n);
-            this.dpush((d / t) | 0);
             this.dpush((d % t) | 0);
+            this.dpush((d / t) | 0);
         },
         '/mod': function () {
             var t = this.dpop() | 0;
             var n = this.dpop() | 0;
-            this.dpush((n / t) | 0);
             this.dpush((n % t) | 0);
+            this.dpush((n / t) | 0);
         },
         nip: function () {
             'swap'();
@@ -159,10 +159,8 @@ function stack (cxt) {
             var t = this.dpop() | 0;
             var n = this.dpop() | 0;
             var s = this.dpop() | 0;
-            var r0 = (s / t) | 0;  // TODO i64 ?
-            var r1 = (s % t) | 0;
-            this.dpush(r1);
-            this.dpush(r0);
+            this.dpush((s % t) | 0); // TODO i64 ?
+            this.dpush((s / t) | 0);
         },
 
         // 6.1.2370 UM/MOD “u-m-slash-mod” (CORE)
@@ -175,10 +173,8 @@ function stack (cxt) {
             var t = this.dpop() >>> 0;
             var n = this.dpop() >>> 0;
             var s = this.dpop() >>> 0;
-            var r0 = (s / t) >>> 0;  // TODO i64 ?
-            var r1 = (s % t) >>> 0;
-            this.dpush(r1);
-            this.dpush(r0);
+            this.dpush((s % t) >>> 0); // TODO i64 ?
+            this.dpush((s / t) >>> 0);
         },
 
         // fm/mod
@@ -192,10 +188,8 @@ function stack (cxt) {
             var t = this.dpop() | 0;
             var n = this.dpop() | 0;
             var s = this.dpop() | 0;
-            var r0 = (s / t) | 0;  // TODO i64 ?
-            var r1 = (s % t) | 0;
-            this.dpush(r1);
-            this.dpush(r0);
+            this.dpush((s % t) | 0); // TODO i64 ?
+            this.dpush((s / t) | 0);
         },
 
         // '?dup': null,
@@ -216,7 +210,7 @@ function stack (cxt) {
     });
 
     // x1 -- x2
-    ' 0< # ((t < 0) ? -1 : 0) ; 0<> # ((t !== 0) ? -1 : 0) ; 0> # ((t > 0) ? -1 : 0) ; 0= # ((t === 0) ? -1 : 0) ; 1+ # (t + 1) | 0 ; 1- # (t - 1) | 0 ; 2* # (t << 1) ; 2/ # (t >> 1) ; abs # Math.abs(t) ; cell+ # (t + 4) ; cells # (t * 4) ; char+ # (t + 1) ; chars # t ; invert # (t ^ -1) ; negate # ((t ^ -1) + 1) | 0 '
+    ' 0< # ((t < 0) ? -1 : 0) ; 0<> # ((t !== 0) ? -1 : 0) ; 0> # ((t > 0) ? -1 : 0) ; 0= # ((t === 0) ? -1 : 0) ; 1+ # (t + 1) | 0 ; 1- # (t - 1) | 0 ; 2* # (t << 1) ; 2/ # (t >> 1) ; abs # Math.abs(t | 0) ; cell+ # (t + 4) ; cells # (t * 4) ; char+ # (t + 1) ; chars # t ; invert # (t ^ -1) ; negate # ((t ^ -1) + 1) | 0 '
     .split(';')
     .map(function (e) { return e.split('#'); })
     .forEach(function (e) {
